@@ -4,6 +4,10 @@ module Serverspec::Type
       @runner.check_group_exists(@name)
     end
 
+    def gid
+      @runner.get_group_gid(@name).stdout.to_i
+    end
+
     def has_gid?(gid)
       @runner.check_group_has_gid(@name, gid)
     end
